﻿using System;
using System.Collections.Generic;

using PT.Scheduler;
using PT.Scheduler.Simulation;
using PT.Scheduler.Simulation.Customizations;

namespace PlanetTogether.Samples.CIP
{
    public class CipRequiredCapacity : RequiredCapacityCustomization
    {
        public override string Name => "CIP Package";
        public override string Description => "Enables CIP based on time or quantity of production.";

        Dictionary<BaseId, TimeSpan> m_activityPostProcessing = new Dictionary<BaseId, TimeSpan>();

        protected override void AfterRequiredCapacityCalculation(BaseActivity a_activity, BaseResource a_resource, RequiredCapacityChangeHelper a_rc, long a_startTicks)
        {
            base.AfterRequiredCapacityCalculation(a_activity, a_resource, a_rc, a_startTicks);

            //This dictionary should be empty on the first action triggered. When the second pass time adjustment is processed, the dictionary should be populated.
            if (m_activityPostProcessing.TryGetValue(a_activity.Id, out TimeSpan postProcessing))
            {
                a_rc.RequiredCapacityChanger.PostProcessingSpan = new RequiredSpan(postProcessing.Ticks, false);
            }
        }

        internal void SetActivityPostProcessing(Dictionary<BaseId, TimeSpan> a_activityPostProcessing)
        {
            m_activityPostProcessing = a_activityPostProcessing;
        }
    }
}
